Class: Google::Apis::CloudresourcemanagerV3::FetchResourceSemanticsResponse
- Inherits:
-
Object
- Object
- Google::Apis::CloudresourcemanagerV3::FetchResourceSemanticsResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudresourcemanager_v3/classes.rb,
lib/google/apis/cloudresourcemanager_v3/representations.rb,
lib/google/apis/cloudresourcemanager_v3/representations.rb
Overview
Response message for FetchResourceSemantics.
Instance Attribute Summary collapse
-
#full_resource_name ⇒ String
The full resource name for which semantics are returned.
-
#semantics ⇒ Hash<String,String>
Map of resource semantics (e.g.,
"ENVIRONMENT": "PRODUCTION").
Instance Method Summary collapse
-
#initialize(**args) ⇒ FetchResourceSemanticsResponse
constructor
A new instance of FetchResourceSemanticsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FetchResourceSemanticsResponse
Returns a new instance of FetchResourceSemanticsResponse.
673 674 675 |
# File 'lib/google/apis/cloudresourcemanager_v3/classes.rb', line 673 def initialize(**args) update!(**args) end |
Instance Attribute Details
#full_resource_name ⇒ String
The full resource name for which semantics are returned. Examples: "//compute.
googleapis.com/projects/123/zones/us-central1-a/instances/my-instance" "//
storage.googleapis.com/projects/_/buckets/my_bucket"
Corresponds to the JSON property fullResourceName
666 667 668 |
# File 'lib/google/apis/cloudresourcemanager_v3/classes.rb', line 666 def full_resource_name @full_resource_name end |
#semantics ⇒ Hash<String,String>
Map of resource semantics (e.g., "ENVIRONMENT": "PRODUCTION").
Corresponds to the JSON property semantics
671 672 673 |
# File 'lib/google/apis/cloudresourcemanager_v3/classes.rb', line 671 def semantics @semantics end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
678 679 680 681 |
# File 'lib/google/apis/cloudresourcemanager_v3/classes.rb', line 678 def update!(**args) @full_resource_name = args[:full_resource_name] if args.key?(:full_resource_name) @semantics = args[:semantics] if args.key?(:semantics) end |