Class: Google::Apis::CloudresourcemanagerV3::Folder
- Inherits:
-
Object
- Object
- Google::Apis::CloudresourcemanagerV3::Folder
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudresourcemanager_v3/classes.rb,
lib/google/apis/cloudresourcemanager_v3/representations.rb,
lib/google/apis/cloudresourcemanager_v3/representations.rb
Overview
A folder in an organization's resource hierarchy, used to organize that organization's resources.
Instance Attribute Summary collapse
-
#configured_capabilities ⇒ Array<String>
Output only.
-
#create_time ⇒ String
Output only.
-
#delete_time ⇒ String
Output only.
-
#display_name ⇒ String
The folder's display name.
-
#etag ⇒ String
Output only.
-
#management_project ⇒ String
Output only.
-
#name ⇒ String
Identifier.
-
#parent ⇒ String
Required.
-
#state ⇒ String
Output only.
-
#tags ⇒ Hash<String,String>
Optional.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Folder
constructor
A new instance of Folder.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Folder
Returns a new instance of Folder.
759 760 761 |
# File 'lib/google/apis/cloudresourcemanager_v3/classes.rb', line 759 def initialize(**args) update!(**args) end |
Instance Attribute Details
#configured_capabilities ⇒ Array<String>
Output only. Optional capabilities configured for this folder (via
UpdateCapability API). Example: folders/123/capabilities/app-management.
Corresponds to the JSON property configuredCapabilities
693 694 695 |
# File 'lib/google/apis/cloudresourcemanager_v3/classes.rb', line 693 def configured_capabilities @configured_capabilities end |
#create_time ⇒ String
Output only. Timestamp when the folder was created.
Corresponds to the JSON property createTime
698 699 700 |
# File 'lib/google/apis/cloudresourcemanager_v3/classes.rb', line 698 def create_time @create_time end |
#delete_time ⇒ String
Output only. Timestamp when the folder was requested to be deleted.
Corresponds to the JSON property deleteTime
703 704 705 |
# File 'lib/google/apis/cloudresourcemanager_v3/classes.rb', line 703 def delete_time @delete_time end |
#display_name ⇒ String
The folder's display name. A folder's display name must be unique amongst its
siblings. For example, no two folders with the same parent can share the same
display name. The display name must start and end with a letter or digit, may
contain letters, digits, spaces, hyphens and underscores and can be no longer
than 30 characters. This is captured by the regular expression: [\pL\pN]([
\pL\pN_- ]0,28[\pL\pN])?.
Corresponds to the JSON property displayName
713 714 715 |
# File 'lib/google/apis/cloudresourcemanager_v3/classes.rb', line 713 def display_name @display_name end |
#etag ⇒ String
Output only. A checksum computed by the server based on the current value of
the folder resource. This may be sent on update and delete requests to ensure
the client has an up-to-date value before proceeding.
Corresponds to the JSON property etag
720 721 722 |
# File 'lib/google/apis/cloudresourcemanager_v3/classes.rb', line 720 def etag @etag end |
#management_project ⇒ String
Output only. Management Project associated with this folder (if app-management
capability is enabled). Example: projects/google-mp-123 OUTPUT ONLY.
Corresponds to the JSON property managementProject
726 727 728 |
# File 'lib/google/apis/cloudresourcemanager_v3/classes.rb', line 726 def management_project @management_project end |
#name ⇒ String
Identifier. The resource name of the folder. Its format is folders/folder_id
, for example: "folders/1234".
Corresponds to the JSON property name
732 733 734 |
# File 'lib/google/apis/cloudresourcemanager_v3/classes.rb', line 732 def name @name end |
#parent ⇒ String
Required. The folder's parent's resource name. Updates to the folder's parent
must be performed using MoveFolder.
Corresponds to the JSON property parent
738 739 740 |
# File 'lib/google/apis/cloudresourcemanager_v3/classes.rb', line 738 def parent @parent end |
#state ⇒ String
Output only. The lifecycle state of the folder. Updates to the state must be
performed using DeleteFolder and UndeleteFolder.
Corresponds to the JSON property state
744 745 746 |
# File 'lib/google/apis/cloudresourcemanager_v3/classes.rb', line 744 def state @state end |
#tags ⇒ Hash<String,String>
Optional. Input only. Immutable. Tag keys/values directly bound to this folder.
Each item in the map must be expressed as " : ". For example: "123/
environment" : "production", "123/costCenter" : "marketing" Note: Currently
this field is in Preview.
Corresponds to the JSON property tags
752 753 754 |
# File 'lib/google/apis/cloudresourcemanager_v3/classes.rb', line 752 def @tags end |
#update_time ⇒ String
Output only. Timestamp when the folder was last modified.
Corresponds to the JSON property updateTime
757 758 759 |
# File 'lib/google/apis/cloudresourcemanager_v3/classes.rb', line 757 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
764 765 766 767 768 769 770 771 772 773 774 775 776 |
# File 'lib/google/apis/cloudresourcemanager_v3/classes.rb', line 764 def update!(**args) @configured_capabilities = args[:configured_capabilities] if args.key?(:configured_capabilities) @create_time = args[:create_time] if args.key?(:create_time) @delete_time = args[:delete_time] if args.key?(:delete_time) @display_name = args[:display_name] if args.key?(:display_name) @etag = args[:etag] if args.key?(:etag) @management_project = args[:management_project] if args.key?(:management_project) @name = args[:name] if args.key?(:name) @parent = args[:parent] if args.key?(:parent) @state = args[:state] if args.key?(:state) @tags = args[:tags] if args.key?(:tags) @update_time = args[:update_time] if args.key?(:update_time) end |