Class: Google::Apis::CloudresourcemanagerV3::Lien
- Inherits:
-
Object
- Object
- Google::Apis::CloudresourcemanagerV3::Lien
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudresourcemanager_v3/classes.rb,
lib/google/apis/cloudresourcemanager_v3/representations.rb,
lib/google/apis/cloudresourcemanager_v3/representations.rb
Overview
A Lien represents an encumbrance on the actions that can be performed on a resource.
Instance Attribute Summary collapse
-
#create_time ⇒ String
The creation time of this Lien.
-
#name ⇒ String
A system-generated unique identifier for this Lien.
-
#origin ⇒ String
A stable, user-visible/meaningful string identifying the origin of the Lien, intended to be inspected programmatically.
-
#parent ⇒ String
A reference to the resource this Lien is attached to.
-
#reason ⇒ String
Concise user-visible strings indicating why an action cannot be performed on a resource.
-
#restrictions ⇒ Array<String>
The types of operations which should be blocked as a result of this Lien.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Lien
constructor
A new instance of Lien.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Lien
Returns a new instance of Lien.
927 928 929 |
# File 'lib/google/apis/cloudresourcemanager_v3/classes.rb', line 927 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
The creation time of this Lien.
Corresponds to the JSON property createTime
892 893 894 |
# File 'lib/google/apis/cloudresourcemanager_v3/classes.rb', line 892 def create_time @create_time end |
#name ⇒ String
A system-generated unique identifier for this Lien. Example: liens/1234abcd
Corresponds to the JSON property name
897 898 899 |
# File 'lib/google/apis/cloudresourcemanager_v3/classes.rb', line 897 def name @name end |
#origin ⇒ String
A stable, user-visible/meaningful string identifying the origin of the Lien,
intended to be inspected programmatically. Maximum length of 200 characters.
Example: 'compute.googleapis.com'
Corresponds to the JSON property origin
904 905 906 |
# File 'lib/google/apis/cloudresourcemanager_v3/classes.rb', line 904 def origin @origin end |
#parent ⇒ String
A reference to the resource this Lien is attached to. The server will validate
the parent against those for which Liens are supported. Example: projects/
1234
Corresponds to the JSON property parent
911 912 913 |
# File 'lib/google/apis/cloudresourcemanager_v3/classes.rb', line 911 def parent @parent end |
#reason ⇒ String
Concise user-visible strings indicating why an action cannot be performed on a
resource. Maximum length of 200 characters. Example: 'Holds production API key'
Corresponds to the JSON property reason
917 918 919 |
# File 'lib/google/apis/cloudresourcemanager_v3/classes.rb', line 917 def reason @reason end |
#restrictions ⇒ Array<String>
The types of operations which should be blocked as a result of this Lien. Each
value should correspond to an IAM permission. The server will validate the
permissions against those for which Liens are supported. An empty list is
meaningless and will be rejected. Example: ['resourcemanager.projects.delete']
Corresponds to the JSON property restrictions
925 926 927 |
# File 'lib/google/apis/cloudresourcemanager_v3/classes.rb', line 925 def restrictions @restrictions end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
932 933 934 935 936 937 938 939 |
# File 'lib/google/apis/cloudresourcemanager_v3/classes.rb', line 932 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @name = args[:name] if args.key?(:name) @origin = args[:origin] if args.key?(:origin) @parent = args[:parent] if args.key?(:parent) @reason = args[:reason] if args.key?(:reason) @restrictions = args[:restrictions] if args.key?(:restrictions) end |