Class: Google::Apis::CloudresourcemanagerV3::Operation
- Inherits:
-
Object
- Object
- Google::Apis::CloudresourcemanagerV3::Operation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudresourcemanager_v3/classes.rb,
lib/google/apis/cloudresourcemanager_v3/representations.rb,
lib/google/apis/cloudresourcemanager_v3/representations.rb
Overview
This resource represents a long-running operation that is the result of a network API call.
Instance Attribute Summary collapse
-
#done ⇒ Boolean
(also: #done?)
If the value is
false, it means the operation is still in progress. -
#error ⇒ Google::Apis::CloudresourcemanagerV3::Status
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#metadata ⇒ Hash<String,Object>
Service-specific metadata associated with the operation.
-
#name ⇒ String
The server-assigned name, which is only unique within the same service that originally returns it.
-
#response ⇒ Hash<String,Object>
The normal, successful response of the operation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Operation
constructor
A new instance of Operation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Operation
Returns a new instance of Operation.
1305 1306 1307 |
# File 'lib/google/apis/cloudresourcemanager_v3/classes.rb', line 1305 def initialize(**args) update!(**args) end |
Instance Attribute Details
#done ⇒ Boolean Also known as: done?
If the value is false, it means the operation is still in progress. If true
, the operation is completed, and either error or response is available.
Corresponds to the JSON property done
1266 1267 1268 |
# File 'lib/google/apis/cloudresourcemanager_v3/classes.rb', line 1266 def done @done end |
#error ⇒ Google::Apis::CloudresourcemanagerV3::Status
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
1277 1278 1279 |
# File 'lib/google/apis/cloudresourcemanager_v3/classes.rb', line 1277 def error @error end |
#metadata ⇒ Hash<String,Object>
Service-specific metadata associated with the operation. It typically contains
progress information and common metadata such as create time. Some services
might not provide such metadata. Any method that returns a long-running
operation should document the metadata type, if any.
Corresponds to the JSON property metadata
1285 1286 1287 |
# File 'lib/google/apis/cloudresourcemanager_v3/classes.rb', line 1285 def @metadata end |
#name ⇒ String
The server-assigned name, which is only unique within the same service that
originally returns it. If you use the default HTTP mapping, the name should
be a resource name ending with operations/unique_id`.
Corresponds to the JSON propertyname`
1292 1293 1294 |
# File 'lib/google/apis/cloudresourcemanager_v3/classes.rb', line 1292 def name @name end |
#response ⇒ Hash<String,Object>
The normal, successful response of the operation. If the original method
returns no data on success, such as Delete, the response is google.protobuf.
Empty. If the original method is standard Get/Create/Update, the
response should be the resource. For other methods, the response should have
the type XxxResponse, where Xxx is the original method name. For example,
if the original method name is TakeSnapshot(), the inferred response type is
TakeSnapshotResponse.
Corresponds to the JSON property response
1303 1304 1305 |
# File 'lib/google/apis/cloudresourcemanager_v3/classes.rb', line 1303 def response @response end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1310 1311 1312 1313 1314 1315 1316 |
# File 'lib/google/apis/cloudresourcemanager_v3/classes.rb', line 1310 def update!(**args) @done = args[:done] if args.key?(:done) @error = args[:error] if args.key?(:error) @metadata = args[:metadata] if args.key?(:metadata) @name = args[:name] if args.key?(:name) @response = args[:response] if args.key?(:response) end |