Class: Google::Apis::CloudresourcemanagerV3::Organization

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudresourcemanager_v3/classes.rb,
lib/google/apis/cloudresourcemanager_v3/representations.rb,
lib/google/apis/cloudresourcemanager_v3/representations.rb

Overview

The root node in the resource hierarchy to which a particular entity's (a company, for example) resources belong.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Organization

Returns a new instance of Organization.



1371
1372
1373
# File 'lib/google/apis/cloudresourcemanager_v3/classes.rb', line 1371

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when the Organization was created. Corresponds to the JSON property createTime

Returns:

  • (String)


1327
1328
1329
# File 'lib/google/apis/cloudresourcemanager_v3/classes.rb', line 1327

def create_time
  @create_time
end

#delete_timeString

Output only. Timestamp when the Organization was requested for deletion. Corresponds to the JSON property deleteTime

Returns:

  • (String)


1332
1333
1334
# File 'lib/google/apis/cloudresourcemanager_v3/classes.rb', line 1332

def delete_time
  @delete_time
end

#directory_customer_idString

Immutable. The G Suite / Workspace customer id used in the Directory API. Corresponds to the JSON property directoryCustomerId

Returns:

  • (String)


1337
1338
1339
# File 'lib/google/apis/cloudresourcemanager_v3/classes.rb', line 1337

def directory_customer_id
  @directory_customer_id
end

#display_nameString

Output only. A human-readable string that refers to the organization in the Google Cloud Console. This string is set by the server and cannot be changed. The string will be set to the primary domain (for example, "google.com") of the Google Workspace customer that owns the organization. Corresponds to the JSON property displayName

Returns:

  • (String)


1345
1346
1347
# File 'lib/google/apis/cloudresourcemanager_v3/classes.rb', line 1345

def display_name
  @display_name
end

#etagString

Output only. A checksum computed by the server based on the current value of the Organization resource. This may be sent on update and delete requests to ensure the client has an up-to-date value before proceeding. Corresponds to the JSON property etag

Returns:

  • (String)


1352
1353
1354
# File 'lib/google/apis/cloudresourcemanager_v3/classes.rb', line 1352

def etag
  @etag
end

#nameString

Output only. The resource name of the organization. This is the organization's relative path in the API. Its format is "organizations/[organization_id]". For example, "organizations/1234". Corresponds to the JSON property name

Returns:

  • (String)


1359
1360
1361
# File 'lib/google/apis/cloudresourcemanager_v3/classes.rb', line 1359

def name
  @name
end

#stateString

Output only. The organization's current lifecycle state. Corresponds to the JSON property state

Returns:

  • (String)


1364
1365
1366
# File 'lib/google/apis/cloudresourcemanager_v3/classes.rb', line 1364

def state
  @state
end

#update_timeString

Output only. Timestamp when the Organization was last modified. Corresponds to the JSON property updateTime

Returns:

  • (String)


1369
1370
1371
# File 'lib/google/apis/cloudresourcemanager_v3/classes.rb', line 1369

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1376
1377
1378
1379
1380
1381
1382
1383
1384
1385
# File 'lib/google/apis/cloudresourcemanager_v3/classes.rb', line 1376

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @delete_time = args[:delete_time] if args.key?(:delete_time)
  @directory_customer_id = args[:directory_customer_id] if args.key?(:directory_customer_id)
  @display_name = args[:display_name] if args.key?(:display_name)
  @etag = args[:etag] if args.key?(:etag)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
  @update_time = args[:update_time] if args.key?(:update_time)
end