Class: Google::Apis::CloudresourcemanagerV3::SearchOrganizationsResponse
- Inherits:
-
Object
- Object
- Google::Apis::CloudresourcemanagerV3::SearchOrganizationsResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudresourcemanager_v3/classes.rb,
lib/google/apis/cloudresourcemanager_v3/representations.rb,
lib/google/apis/cloudresourcemanager_v3/representations.rb
Overview
The response returned from the SearchOrganizations method.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A pagination token to be used to retrieve the next page of results.
-
#organizations ⇒ Array<Google::Apis::CloudresourcemanagerV3::Organization>
The list of Organizations that matched the search query, possibly paginated.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SearchOrganizationsResponse
constructor
A new instance of SearchOrganizationsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SearchOrganizationsResponse
Returns a new instance of SearchOrganizationsResponse.
1671 1672 1673 |
# File 'lib/google/apis/cloudresourcemanager_v3/classes.rb', line 1671 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A pagination token to be used to retrieve the next page of results. If the
result is too large to fit within the page size specified in the request, this
field will be set with a token that can be used to fetch the next page of
results. If this field is empty, it indicates that this response contains the
last page of results.
Corresponds to the JSON property nextPageToken
1664 1665 1666 |
# File 'lib/google/apis/cloudresourcemanager_v3/classes.rb', line 1664 def next_page_token @next_page_token end |
#organizations ⇒ Array<Google::Apis::CloudresourcemanagerV3::Organization>
The list of Organizations that matched the search query, possibly paginated.
Corresponds to the JSON property organizations
1669 1670 1671 |
# File 'lib/google/apis/cloudresourcemanager_v3/classes.rb', line 1669 def organizations @organizations end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1676 1677 1678 1679 |
# File 'lib/google/apis/cloudresourcemanager_v3/classes.rb', line 1676 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @organizations = args[:organizations] if args.key?(:organizations) end |