Class: Google::Apis::CloudresourcemanagerV3::TagBinding
- Inherits:
-
Object
- Object
- Google::Apis::CloudresourcemanagerV3::TagBinding
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudresourcemanager_v3/classes.rb,
lib/google/apis/cloudresourcemanager_v3/representations.rb,
lib/google/apis/cloudresourcemanager_v3/representations.rb
Overview
A TagBinding represents a connection between a TagValue and a cloud resource. When a TagBinding is created, the TagValue is applied to all the descendants of the Google Cloud resource.
Instance Attribute Summary collapse
-
#name ⇒ String
Output only.
-
#parent ⇒ String
The full resource name of the resource the TagValue is bound to.
-
#tag_value ⇒ String
The TagValue of the TagBinding.
-
#tag_value_namespaced_name ⇒ String
The namespaced name for the TagValue of the TagBinding.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TagBinding
constructor
A new instance of TagBinding.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TagBinding
Returns a new instance of TagBinding.
1841 1842 1843 |
# File 'lib/google/apis/cloudresourcemanager_v3/classes.rb', line 1841 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
Output only. The name of the TagBinding. This is a String of the form:
tagBindings/full-resource-name/tag-value-name(e.g. `tagBindings/%2F%
2Fcloudresourcemanager.googleapis.com%2Fprojects%2F123/tagValues/456`) or `
tagBindings/`full-resource-name`/`tag-key-name (e.g. tagBindings/%2F%
2Fcloudresourcemanager.googleapis.com%2Fprojects%2F123/tagKeys/123).
Corresponds to the JSON property name
1820 1821 1822 |
# File 'lib/google/apis/cloudresourcemanager_v3/classes.rb', line 1820 def name @name end |
#parent ⇒ String
The full resource name of the resource the TagValue is bound to. E.g. //
cloudresourcemanager.googleapis.com/projects/123
Corresponds to the JSON property parent
1826 1827 1828 |
# File 'lib/google/apis/cloudresourcemanager_v3/classes.rb', line 1826 def parent @parent end |
#tag_value ⇒ String
The TagValue of the TagBinding. Must be of the form tagValues/456.
Corresponds to the JSON property tagValue
1831 1832 1833 |
# File 'lib/google/apis/cloudresourcemanager_v3/classes.rb', line 1831 def tag_value @tag_value end |
#tag_value_namespaced_name ⇒ String
The namespaced name for the TagValue of the TagBinding. Must be in the format
parent_id/tag_key_short_name/short_name`. For methods that support
TagValue namespaced name, only one of tag_value_namespaced_name or tag_value
may be filled. Requests with both fields will be rejected.
Corresponds to the JSON propertytagValueNamespacedName`
1839 1840 1841 |
# File 'lib/google/apis/cloudresourcemanager_v3/classes.rb', line 1839 def tag_value_namespaced_name @tag_value_namespaced_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1846 1847 1848 1849 1850 1851 |
# File 'lib/google/apis/cloudresourcemanager_v3/classes.rb', line 1846 def update!(**args) @name = args[:name] if args.key?(:name) @parent = args[:parent] if args.key?(:parent) @tag_value = args[:tag_value] if args.key?(:tag_value) @tag_value_namespaced_name = args[:tag_value_namespaced_name] if args.key?(:tag_value_namespaced_name) end |