Class: Google::Apis::CloudresourcemanagerV3::TagBindingCollection

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudresourcemanager_v3/classes.rb,
lib/google/apis/cloudresourcemanager_v3/representations.rb,
lib/google/apis/cloudresourcemanager_v3/representations.rb

Overview

Represents a collection of tags directly bound to a GCP resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TagBindingCollection

Returns a new instance of TagBindingCollection.



1885
1886
1887
# File 'lib/google/apis/cloudresourcemanager_v3/classes.rb', line 1885

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Optional. A checksum based on the current bindings which can be passed to prevent race conditions. This field is always set in server responses. Corresponds to the JSON property etag

Returns:

  • (String)


1862
1863
1864
# File 'lib/google/apis/cloudresourcemanager_v3/classes.rb', line 1862

def etag
  @etag
end

#full_resource_nameString

The full resource name of the resource the TagBindings are bound to. E.g. // cloudresourcemanager.googleapis.com/projects/123 Corresponds to the JSON property fullResourceName

Returns:

  • (String)


1868
1869
1870
# File 'lib/google/apis/cloudresourcemanager_v3/classes.rb', line 1868

def full_resource_name
  @full_resource_name
end

#nameString

Identifier. The name of the TagBindingCollection, following the convention: locations/location/tagBindingCollections/encoded-full-resource-name`where the encoded-full-resource-name is the UTF-8 encoded name of the GCP resource the TagBindings are bound to. "locations/global/tagBindingCollections/%2f% 2fcloudresourcemanager.googleapis.com%2fprojects%2f123" Corresponds to the JSON propertyname`

Returns:

  • (String)


1877
1878
1879
# File 'lib/google/apis/cloudresourcemanager_v3/classes.rb', line 1877

def name
  @name
end

#tagsHash<String,String>

Tag keys/values directly bound to this resource, specified in namespaced format. For example: "123/environment": "production" Corresponds to the JSON property tags

Returns:

  • (Hash<String,String>)


1883
1884
1885
# File 'lib/google/apis/cloudresourcemanager_v3/classes.rb', line 1883

def tags
  @tags
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1890
1891
1892
1893
1894
1895
# File 'lib/google/apis/cloudresourcemanager_v3/classes.rb', line 1890

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @full_resource_name = args[:full_resource_name] if args.key?(:full_resource_name)
  @name = args[:name] if args.key?(:name)
  @tags = args[:tags] if args.key?(:tags)
end