Class: Google::Apis::CloudresourcemanagerV3::TagHold

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudresourcemanager_v3/classes.rb,
lib/google/apis/cloudresourcemanager_v3/representations.rb,
lib/google/apis/cloudresourcemanager_v3/representations.rb

Overview

A TagHold represents the use of a TagValue that is not captured by TagBindings. If a TagValue has any TagHolds, deletion will be blocked. This resource is intended to be created in the same cloud location as the holder.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TagHold

Returns a new instance of TagHold.



1937
1938
1939
# File 'lib/google/apis/cloudresourcemanager_v3/classes.rb', line 1937

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The time this TagHold was created. Corresponds to the JSON property createTime

Returns:

  • (String)


1907
1908
1909
# File 'lib/google/apis/cloudresourcemanager_v3/classes.rb', line 1907

def create_time
  @create_time
end

Optional. A URL where an end user can learn more about removing this hold. E.g. https://cloud.google.com/resource-manager/docs/tags/tags-creating-and- managing Corresponds to the JSON property helpLink

Returns:

  • (String)


1914
1915
1916
# File 'lib/google/apis/cloudresourcemanager_v3/classes.rb', line 1914

def help_link
  @help_link
end

#holderString

Required. The name of the resource where the TagValue is being used. Must be less than 200 characters. E.g. //compute.googleapis.com/compute/projects/ myproject/regions/us-east-1/instanceGroupManagers/instance-group Corresponds to the JSON property holder

Returns:

  • (String)


1921
1922
1923
# File 'lib/google/apis/cloudresourcemanager_v3/classes.rb', line 1921

def holder
  @holder
end

#nameString

Output only. The resource name of a TagHold. This is a String of the form: tagValues/tag-value-id/tagHolds/tag-hold-id`(e.g.tagValues/123/tagHolds/ 456). This resource name is generated by the server. Corresponds to the JSON propertyname`

Returns:

  • (String)


1928
1929
1930
# File 'lib/google/apis/cloudresourcemanager_v3/classes.rb', line 1928

def name
  @name
end

#originString

Optional. An optional string representing the origin of this request. This field should include human-understandable information to distinguish origins from each other. Must be less than 200 characters. E.g. migs-35678234 Corresponds to the JSON property origin

Returns:

  • (String)


1935
1936
1937
# File 'lib/google/apis/cloudresourcemanager_v3/classes.rb', line 1935

def origin
  @origin
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1942
1943
1944
1945
1946
1947
1948
# File 'lib/google/apis/cloudresourcemanager_v3/classes.rb', line 1942

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @help_link = args[:help_link] if args.key?(:help_link)
  @holder = args[:holder] if args.key?(:holder)
  @name = args[:name] if args.key?(:name)
  @origin = args[:origin] if args.key?(:origin)
end