Class: Google::Apis::CloudresourcemanagerV3::TagBinding

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudresourcemanager_v3/classes.rb,
lib/google/apis/cloudresourcemanager_v3/representations.rb,
lib/google/apis/cloudresourcemanager_v3/representations.rb

Overview

A TagBinding represents a connection between a TagValue and a cloud resource. When a TagBinding is created, the TagValue is applied to all the descendants of the Google Cloud resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TagBinding

Returns a new instance of TagBinding.



1814
1815
1816
# File 'lib/google/apis/cloudresourcemanager_v3/classes.rb', line 1814

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

Output only. The name of the TagBinding. This is a String of the form: tagBindings/full-resource-name/tag-value-name(e.g. `tagBindings/%2F% 2Fcloudresourcemanager.googleapis.com%2Fprojects%2F123/tagValues/456`) or ` tagBindings/`full-resource-name`/`tag-key-name (e.g. tagBindings/%2F% 2Fcloudresourcemanager.googleapis.com%2Fprojects%2F123/tagKeys/123). Corresponds to the JSON property name

Returns:

  • (String)


1793
1794
1795
# File 'lib/google/apis/cloudresourcemanager_v3/classes.rb', line 1793

def name
  @name
end

#parentString

The full resource name of the resource the TagValue is bound to. E.g. // cloudresourcemanager.googleapis.com/projects/123 Corresponds to the JSON property parent

Returns:

  • (String)


1799
1800
1801
# File 'lib/google/apis/cloudresourcemanager_v3/classes.rb', line 1799

def parent
  @parent
end

#tag_valueString

The TagValue of the TagBinding. Must be of the form tagValues/456. Corresponds to the JSON property tagValue

Returns:

  • (String)


1804
1805
1806
# File 'lib/google/apis/cloudresourcemanager_v3/classes.rb', line 1804

def tag_value
  @tag_value
end

#tag_value_namespaced_nameString

The namespaced name for the TagValue of the TagBinding. Must be in the format parent_id/tag_key_short_name/short_name`. For methods that support TagValue namespaced name, only one of tag_value_namespaced_name or tag_value may be filled. Requests with both fields will be rejected. Corresponds to the JSON propertytagValueNamespacedName`

Returns:

  • (String)


1812
1813
1814
# File 'lib/google/apis/cloudresourcemanager_v3/classes.rb', line 1812

def tag_value_namespaced_name
  @tag_value_namespaced_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1819
1820
1821
1822
1823
1824
# File 'lib/google/apis/cloudresourcemanager_v3/classes.rb', line 1819

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @parent = args[:parent] if args.key?(:parent)
  @tag_value = args[:tag_value] if args.key?(:tag_value)
  @tag_value_namespaced_name = args[:tag_value_namespaced_name] if args.key?(:tag_value_namespaced_name)
end