Class: Google::Apis::CloudresourcemanagerV3::TagHold

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudresourcemanager_v3/classes.rb,
lib/google/apis/cloudresourcemanager_v3/representations.rb,
lib/google/apis/cloudresourcemanager_v3/representations.rb

Overview

A TagHold represents the use of a TagValue that is not captured by TagBindings. If a TagValue has any TagHolds, deletion will be blocked. This resource is intended to be created in the same cloud location as the holder.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TagHold

Returns a new instance of TagHold.



1910
1911
1912
# File 'lib/google/apis/cloudresourcemanager_v3/classes.rb', line 1910

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The time this TagHold was created. Corresponds to the JSON property createTime

Returns:

  • (String)


1880
1881
1882
# File 'lib/google/apis/cloudresourcemanager_v3/classes.rb', line 1880

def create_time
  @create_time
end

Optional. A URL where an end user can learn more about removing this hold. E.g. https://cloud.google.com/resource-manager/docs/tags/tags-creating-and- managing Corresponds to the JSON property helpLink

Returns:

  • (String)


1887
1888
1889
# File 'lib/google/apis/cloudresourcemanager_v3/classes.rb', line 1887

def help_link
  @help_link
end

#holderString

Required. The name of the resource where the TagValue is being used. Must be less than 200 characters. E.g. //compute.googleapis.com/compute/projects/ myproject/regions/us-east-1/instanceGroupManagers/instance-group Corresponds to the JSON property holder

Returns:

  • (String)


1894
1895
1896
# File 'lib/google/apis/cloudresourcemanager_v3/classes.rb', line 1894

def holder
  @holder
end

#nameString

Output only. The resource name of a TagHold. This is a String of the form: tagValues/tag-value-id/tagHolds/tag-hold-id`(e.g.tagValues/123/tagHolds/ 456). This resource name is generated by the server. Corresponds to the JSON propertyname`

Returns:

  • (String)


1901
1902
1903
# File 'lib/google/apis/cloudresourcemanager_v3/classes.rb', line 1901

def name
  @name
end

#originString

Optional. An optional string representing the origin of this request. This field should include human-understandable information to distinguish origins from each other. Must be less than 200 characters. E.g. migs-35678234 Corresponds to the JSON property origin

Returns:

  • (String)


1908
1909
1910
# File 'lib/google/apis/cloudresourcemanager_v3/classes.rb', line 1908

def origin
  @origin
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1915
1916
1917
1918
1919
1920
1921
# File 'lib/google/apis/cloudresourcemanager_v3/classes.rb', line 1915

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @help_link = args[:help_link] if args.key?(:help_link)
  @holder = args[:holder] if args.key?(:holder)
  @name = args[:name] if args.key?(:name)
  @origin = args[:origin] if args.key?(:origin)
end