Class: Google::Apis::CloudresourcemanagerV3::TagValue
- Inherits:
-
Object
- Object
- Google::Apis::CloudresourcemanagerV3::TagValue
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudresourcemanager_v3/classes.rb,
lib/google/apis/cloudresourcemanager_v3/representations.rb,
lib/google/apis/cloudresourcemanager_v3/representations.rb
Overview
A TagValue is a child of a particular TagKey. This is used to group cloud resources for the purpose of controlling them using policies.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#etag ⇒ String
Optional.
-
#name ⇒ String
Immutable.
-
#namespaced_name ⇒ String
Output only.
-
#parent ⇒ String
Immutable.
-
#short_name ⇒ String
Required.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TagValue
constructor
A new instance of TagValue.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TagValue
Returns a new instance of TagValue.
2076 2077 2078 |
# File 'lib/google/apis/cloudresourcemanager_v3/classes.rb', line 2076 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Creation time.
Corresponds to the JSON property createTime
2029 2030 2031 |
# File 'lib/google/apis/cloudresourcemanager_v3/classes.rb', line 2029 def create_time @create_time end |
#description ⇒ String
Optional. User-assigned description of the TagValue. Must not exceed 256
characters. Read-write.
Corresponds to the JSON property description
2035 2036 2037 |
# File 'lib/google/apis/cloudresourcemanager_v3/classes.rb', line 2035 def description @description end |
#etag ⇒ String
Optional. Entity tag which users can pass to prevent race conditions. This
field is always set in server responses. See UpdateTagValueRequest for details.
Corresponds to the JSON property etag
2041 2042 2043 |
# File 'lib/google/apis/cloudresourcemanager_v3/classes.rb', line 2041 def etag @etag end |
#name ⇒ String
Immutable. Resource name for TagValue in the format tagValues/456.
Corresponds to the JSON property name
2046 2047 2048 |
# File 'lib/google/apis/cloudresourcemanager_v3/classes.rb', line 2046 def name @name end |
#namespaced_name ⇒ String
Output only. The namespaced name of the TagValue. Can be in the form
organization_id`/`tag_key_short_name`/`tag_value_short_name or project_id`/
`tag_key_short_name`/`tag_value_short_name or project_number`/`
tag_key_short_name`/`tag_value_short_name.
Corresponds to the JSON property namespacedName
2054 2055 2056 |
# File 'lib/google/apis/cloudresourcemanager_v3/classes.rb', line 2054 def namespaced_name @namespaced_name end |
#parent ⇒ String
Immutable. The resource name of the new TagValue's parent TagKey. Must be of
the form tagKeys/tag_key_id`.
Corresponds to the JSON propertyparent`
2060 2061 2062 |
# File 'lib/google/apis/cloudresourcemanager_v3/classes.rb', line 2060 def parent @parent end |
#short_name ⇒ String
Required. Immutable. User-assigned short name for TagValue. The short name
should be unique for TagValues within the same parent TagKey. The short name
must be 256 characters or less, beginning and ending with an alphanumeric
character ([a-z0-9A-Z]) with dashes (-), underscores (_), dots (.), and
alphanumerics between.
Corresponds to the JSON property shortName
2069 2070 2071 |
# File 'lib/google/apis/cloudresourcemanager_v3/classes.rb', line 2069 def short_name @short_name end |
#update_time ⇒ String
Output only. Update time.
Corresponds to the JSON property updateTime
2074 2075 2076 |
# File 'lib/google/apis/cloudresourcemanager_v3/classes.rb', line 2074 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2081 2082 2083 2084 2085 2086 2087 2088 2089 2090 |
# File 'lib/google/apis/cloudresourcemanager_v3/classes.rb', line 2081 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @etag = args[:etag] if args.key?(:etag) @name = args[:name] if args.key?(:name) @namespaced_name = args[:namespaced_name] if args.key?(:namespaced_name) @parent = args[:parent] if args.key?(:parent) @short_name = args[:short_name] if args.key?(:short_name) @update_time = args[:update_time] if args.key?(:update_time) end |